@@ -3,6 +3,9 @@ import h5py
 from matplotlib import pyplot as plt
 
 DictionaryEntry = np.dtype([('T1', np.float32), ('T2', np.float32), ('B1', np.float32)])
+WHITE_MATTER_3T = np.array([(0.8, 0.04, 1.)],dtype=DictionaryEntry)
+GREY_MATTER_3T = np.array([(1.200, 0.065, 1.)],dtype=DictionaryEntry)
+CSF_3T = np.array([(3.000, 0.500, 1.)],dtype=DictionaryEntry)
 
 class DictionaryParameters:
     def __init__(self, name, entries=[]):
