@@ -132,8 +132,7 @@ class Simulation:
                 lastDictEntry = len(self.dictionaryParameters.entries)
             else:
                 lastDictEntry = firstDictEntry+dictEntriesPerBatch
-            print(firstDictEntry)
-            print(lastDictEntry)
+            print("Starting Batch: " + str(i) + " (Entries " + str(firstDictEntry) + "->" + str(lastDictEntry)+ ")")
             T1s.clear();T2s.clear();B1s.clear()
             for dictionaryEntry in self.dictionaryParameters.entries[firstDictEntry:lastDictEntry]:
                 T1s.append(dictionaryEntry['T1'])
